@@ -17,8 +17,13 @@
 #' @rdname fone
 #' @examples
 #' \dontrun{
-#' fone_dataset(dataset_id = "DS00047", resource_id = "RS00005")
-#' fone_view(view_id = "DS01538")
+#' # get dataset data
+#' dataset <- fone_dataset(dataset_id = "DS00047", resource_id = "RS00005")
+#' head(dataset)
+#'
+#' # get view data
+#' view <- fone_view(view_id = "DS01538")
+#' head(view)
 #' }
 fone_dataset <- function(dataset_id, resource_id, ..., limit = NULL) {
   stopifnot(
@@ -26,13 +31,14 @@ fone_dataset <- function(dataset_id, resource_id, ..., limit = NULL) {
     is_string(resource_id),
     is_count(limit, null_ok = TRUE)
   )
-  fone(
+  res <- fone(
     resource = "apiservice",
     datasetId = dataset_id,
     resourceId = resource_id,
     ...,
     limit = limit
   )
+  clean_strings(res)
 }
 
 #' @rdname fone
@@ -49,7 +55,8 @@ fone <- function(resource, ..., limit = NULL) {
     req_user_agent("worldbank (https://m-muecke.github.io/worldbank)") |>
     req_error(body = \(resp) resp_body_string(resp, "UTF-8")) |>
     req_url_path_append(resource) |>
-    req_url_query(top = limit, type = "csv", ...)
+    req_url_query(top = limit, type = "csv", ...) |>
+    req_wb_cache()
 
   resps <- req_perform_iterative(
     req,
